summaryrefslogtreecommitdiff
path: root/lib-src
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2011-02-25 16:23:33 -0800
committerPaul Eggert <eggert@cs.ucla.edu>2011-02-25 16:23:33 -0800
commit70279bd1cbd56a16b39cb09ac0b47b564db6949b (patch)
tree2a9e29472946b6e7398430fb4ebe38f370bb70e0 /lib-src
parent34e6d7823aeee6c20219bbab1045ca6649ca8fa5 (diff)
downloademacs-70279bd1cbd56a16b39cb09ac0b47b564db6949b.tar.gz
* ebrowse.c (insert_keyword): Rename parameter to avoid shadowing diagnostic.
Diffstat (limited to 'lib-src')
-rw-r--r--lib-src/ChangeLog1
-rw-r--r--lib-src/ebrowse.c6
2 files changed, 4 insertions, 3 deletions
diff --git a/lib-src/ChangeLog b/lib-src/ChangeLog
index 969a84ca6bf..ed6162bc997 100644
--- a/lib-src/ChangeLog
+++ b/lib-src/ChangeLog
@@ -3,6 +3,7 @@
* ebrowse.c (putstr): Rename from PUTSTR and turn into a function.
All callers changed. This is cleaner, and avoids GCC warnings about
passing NULL to fputs.
+ (insert_keyword): Rename parameter to avoid shadowing diagnostic.
2011-02-25 Paul Eggert <eggert@cs.ucla.edu>
diff --git a/lib-src/ebrowse.c b/lib-src/ebrowse.c
index bc537ec719c..60baf99c511 100644
--- a/lib-src/ebrowse.c
+++ b/lib-src/ebrowse.c
@@ -2063,11 +2063,11 @@ re_init_scanner (void)
}
/* Insert a keyword NAME with token value TK into the keyword hash
table. */
static void
-insert_keyword (const char *name, int tk)
+insert_keyword (const char *name, int tkv)
{
const char *s;
unsigned h = 0;
@@ -2078,7 +2078,7 @@ insert_keyword (const char *name, int tk)
h %= KEYWORD_TABLE_SIZE;
k->name = name;
- k->tk = tk;
+ k->tk = tkv;
k->next = keyword_table[h];
keyword_table[h] = k;
}
@@ -2063,11 +2063,11 @@ re_init_scanner (void)
}
-/* Insert a keyword NAME with token value TK into the keyword hash
+/* Insert a keyword NAME with token value TKV into the keyword hash
table. */
static void